==> fred_ferda_auction-0.2.0rc1-py3-none-any.whl: ferda_auction/api.py <==
"""Ferda auction API."""

from typing import cast
from urllib.parse import urljoin

from asgiref.sync import sync_to_async
from django.http import HttpRequest
from ferda.api import check_permissions
from ferda.constants import LOGGER_SESSION_KEY
from httpx import AsyncClient
from ninja import Router, Schema

from .constants import ApiScope
from .settings import SETTINGS

router = Router(tags=["auction"])


class AccessTokenResponse(Schema):
    """Access token response."""

    access_token: str


async def _has_perm(request: HttpRequest, perm: str) -> bool:
    return cast(bool, await sync_to_async(request.user.has_perm)(perm))


@router.get("/auth")
async def get_access_token(request: HttpRequest) -> AccessTokenResponse:
    """Get access token with maximum privileges for given user."""
    await sync_to_async(check_permissions)(request, permissions=["ferda_auction.can_view"])

    scopes = []

    if await _has_perm(request, "ferda_auction.can_view_all"):
        scopes.append(ApiScope.AUCTION_READ_FULL)
    if await _has_perm(request, "ferda_auction.can_edit_auction"):
        scopes.append(ApiScope.AUCTION_EDIT)
    if await _has_perm(request, "ferda_auction.can_edit_ban"):
        scopes.extend([ApiScope.BAN_READ, ApiScope.BAN_EDIT])

    if SETTINGS.api_username:
        auth = (SETTINGS.api_username, SETTINGS.api_password)
    else:
        auth = None

    async with AsyncClient(verify=SETTINGS.ca_certs, auth=auth) as client:
        response = await client.post(
            urljoin(SETTINGS.api_url, "v1/auth/login/admin/"),
            json={
                "logger_session_id": request.session.get(LOGGER_SESSION_KEY),
                "scopes": scopes,
            },
        )
        return AccessTokenResponse(**response.json())

==> fred_ferda_auction-0.5.0rc3-py3-none-any.whl: ferda_auction/api.py <==
"""Ferda auction API."""

from typing import cast
from urllib.parse import urljoin

from asgiref.sync import sync_to_async
from django.http import HttpRequest
from ferda.api import check_permissions
from ferda.constants import LOGGER_SESSION_KEY
from httpx import AsyncClient
from ninja import Router, Schema

from .constants import ApiScope
from .settings import SETTINGS

router = Router(tags=["auction"])


class AccessTokenResponse(Schema):
    """Access token response."""

    access_token: str


async def _has_perm(request: HttpRequest, perm: str) -> bool:
    return cast(bool, await sync_to_async(request.user.has_perm)(perm))


@router.get("/auth")
async def get_access_token(request: HttpRequest) -> AccessTokenResponse:
    """Get access token with maximum privileges for given user."""
    await sync_to_async(check_permissions)(request, permissions=["ferda_auction.can_view"])

    scopes = set()

    if await _has_perm(request, "ferda_auction.can_view_all"):
        scopes.add(ApiScope.AUCTION_READ_FULL)
    if await _has_perm(request, "ferda_auction.can_edit_auction"):
        scopes.add(ApiScope.AUCTION_EDIT)
    if await _has_perm(request, "ferda_auction.can_view_ban"):
        scopes.add(ApiScope.BAN_READ)
    if await _has_perm(request, "ferda_auction.can_edit_ban"):
        scopes.update({ApiScope.BAN_READ, ApiScope.BAN_EDIT})

    if SETTINGS.api_username:
        auth = (SETTINGS.api_username, SETTINGS.api_password)
    else:
        auth = None

    async with AsyncClient(verify=SETTINGS.ca_certs, auth=auth) as client:
        response = await client.post(
            urljoin(SETTINGS.api_url, "v1/auth/login/admin/"),
            json={
                "logger_session_id": request.session.get(LOGGER_SESSION_KEY),
                "scopes": list(scopes),
            },
        )
        return AccessTokenResponse(**response.json())
